==> rospell-2007.01.rc3.tar.gz: rospell-2007.01.rc3/src/rospell/ctagsdialog.cpp <==
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


#include "ctagsdialog.h"
#ifdef USING_QT4
#include <Q3VBoxLayout>
#include <q3hbox.h>
#include <q3accel.h>
#include <QLabel>
#endif
#ifdef USING_QT3
#include <qlayout.h>
#include <qhbox.h>
#include <qaccel.h>
#include <qlabel.h>
#endif

#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>


//*****************************************************************************/
// ctags dialog
//*****************************************************************************/
CtagsDialog::CtagsDialog(): QDialog(0, "ctags selection", true) {
	Q3VBoxLayout *vly = new Q3VBoxLayout(this, 10, 10);
	vly->setAutoAdd(true);

	Q3HBox *hbox3 = new Q3HBox(this);
	hbox3->setSpacing(10);

	// standard c library help file
#ifdef    ENABLE_STDLIBC_CTAGS
	load_stdlib_ = new QCheckBox("Load Standard C Library tags", hbox3);
	if (Global::instance()->load_glibc_tags)
#ifdef USING_QT4
		load_stdlib_->setOn(true);
#else
		load_stdlib_->setChecked(true);
#endif	
#endif //ENABLE_STDLIBC_CTAGS

	// posix headers help file
#ifdef    ENABLE_POSIXH_CTAGS
	Q3HBox *hbox33 = new Q3HBox(this);
	hbox33->setSpacing(10);
	load_posixh_ = new QCheckBox("Load POSIX headers tags", hbox33);
	if (Global::instance()->load_posixh_tags)
#ifdef USING_QT4
		load_posixh_->setOn(true);
#else
		load_posixh_->setChecked(true);
#endif	
#endif //ENABLE_POSIXH_CTAGS

	// latex help file
#ifdef    ENABLE_LATEX_CTAGS
	Q3HBox *hbox31 = new Q3HBox(this);
	hbox31->setSpacing(10);

	load_latex_ = new QCheckBox("Load LaTeX tags", hbox31);
	if (Global::instance()->load_latex_tags)
#ifdef USING_QT4
		load_latex_->setOn(true);
#else
		load_latex_->setChecked(true);
#endif	
#endif //ENABLE_LATEX_CTAGS


	// some empty space
	Q3HBox *hbox21 = new Q3HBox(this);
	hbox21->setMargin(3);

	// generate local tags
	Q3HBox *hbox32 = new Q3HBox(this);
	hbox32->setSpacing(10);

	generate_local_tags_ = new QCheckBox("Generate local tags", hbox32);
	if (Global::instance()->generate_local_tags)
#ifdef USING_QT4
		generate_local_tags_->setOn(true);
#else
		generate_local_tags_->setChecked(true);
#endif	
	Q3HBox *hbox1 = new Q3HBox(this);
	hbox1->setSpacing(10);
	new QLabel("command: ", hbox1);
	cmd_ = new QLineEdit(hbox1);
	if ((Global::instance()->tags_cmd).isEmpty()) {
		// use exuberant-ctags on linux, exctags on freebsd
#ifdef ROSPELL_FREEBSD	
		cmd_->setText("exctags -e -R . 2>&1");
#else
		cmd_->setText("exuberant-ctags -e -R . 2>&1");
#endif		
	}
	else
		cmd_->setText(Global::instance()->tags_cmd);

	// some empty space
	Q3HBox *hbox20 = new Q3HBox(this);
	hbox20->setMargin(10);

	// accept/reject
	Q3HBox *hbox2 = new Q3HBox(this);
	hbox2->setSpacing(10);
	// some empty space
	(new QWidget(hbox2))->setMinimumWidth(80);
	(new QWidget(hbox2))->setMinimumWidth(80);
	button_reload_ = new QPushButton("Reload tags", hbox2);
	button_cancel_ = new QPushButton("Cancel", hbox2);
	connect(button_reload_, SIGNAL(clicked()), SLOT(accept()));
	connect(button_cancel_, SIGNAL(clicked()), SLOT(reject()));




//	setSizeGripEnabled(true);
}

bool CtagsDialog::getLibc() {
#ifdef    ENABLE_STDLIBC_CTAGS
	return load_stdlib_->isChecked();
#else
	return false;
#endif
}

bool CtagsDialog::getPosixh() {
#ifdef    ENABLE_POSIXH_CTAGS
	return load_posixh_->isChecked();
#else
	return false;
#endif
}
bool CtagsDialog::getLatex() {
#ifdef    ENABLE_LATEX_CTAGS
	return load_latex_->isChecked();
#else
	return false;
#endif
}

bool CtagsDialog::getGenerateLocalTags() {
	return generate_local_tags_->isChecked();
}

QString CtagsDialog::getCmd() {
	return cmd_->text();
}

==> rospell-2007.02.rc1.tar.gz: rospell-2007.02.rc1/src/rospell/ctagsdialog.cpp <==
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


#include "ctagsdialog.h"
#ifdef USING_QT4
#include <Q3VBoxLayout>
#include <q3hbox.h>
#include <q3accel.h>
#include <QLabel>
#endif
#ifdef USING_QT3
#include <qlayout.h>
#include <qhbox.h>
#include <qaccel.h>
#include <qlabel.h>
#endif

#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qbuttongroup.h>


//*****************************************************************************/
// ctags dialog
//*****************************************************************************/
CtagsDialog::CtagsDialog(): QDialog(0, "ctags selection", true) {
	Q3VBoxLayout *vly = new Q3VBoxLayout(this, 10, 10);
	vly->setAutoAdd(true);

            QButtonGroup *gr = new QButtonGroup( 1, QGroupBox::Horizontal, "Library Tags", this );
	gr->setExclusive(FALSE);

	// standard c library help file
#ifdef    ENABLE_STDLIBC_CTAGS
	load_stdlib_ = new QCheckBox("Standard C Library", gr);
	if (Global::instance()->load_glibc_tags)
#ifdef USING_QT4
		load_stdlib_->setOn(true);
#else
		load_stdlib_->setChecked(true);
#endif	
#endif //ENABLE_STDLIBC_CTAGS

	// posix headers help file
#ifdef    ENABLE_POSIXH_CTAGS
	load_posixh_ = new QCheckBox("POSIX Library", gr);
	if (Global::instance()->load_posixh_tags)
#ifdef USING_QT4
		load_posixh_->setOn(true);
#else
		load_posixh_->setChecked(true);
#endif	
#endif //ENABLE_POSIXH_CTAGS

	// latex help file
#ifdef    ENABLE_LATEX_CTAGS
	load_latex_ = new QCheckBox("LaTeX Help", gr);
	if (Global::instance()->load_latex_tags)
#ifdef USING_QT4
		load_latex_->setOn(true);
#else
		load_latex_->setChecked(true);
#endif	
#endif //ENABLE_LATEX_CTAGS


	// some empty space
	Q3HBox *hbox21 = new Q3HBox(this);
	hbox21->setMargin(3);

	// generate local tags
	Q3HBox *hbox32 = new Q3HBox(this);
	hbox32->setSpacing(10);

	generate_local_tags_ = new QCheckBox("Generate local tags", hbox32);
	if (Global::instance()->generate_local_tags)
#ifdef USING_QT4
		generate_local_tags_->setOn(true);
#else
		generate_local_tags_->setChecked(true);
#endif	
	Q3HBox *hbox1 = new Q3HBox(this);
	hbox1->setSpacing(10);
	new QLabel("command: ", hbox1);
	cmd_ = new QLineEdit(hbox1);
	if ((Global::instance()->tags_cmd).isEmpty()) {
		// use exuberant-ctags on linux, exctags on freebsd
#ifdef ROSPELL_FREEBSD	
		cmd_->setText("exctags -e -R . 2>&1");
#else
		cmd_->setText("exuberant-ctags -e -R . 2>&1");
#endif		
	}
	else
		cmd_->setText(Global::instance()->tags_cmd);

	// some empty space
	Q3HBox *hbox20 = new Q3HBox(this);
	hbox20->setMargin(10);

	// accept/reject
	Q3HBox *hbox2 = new Q3HBox(this);
	hbox2->setSpacing(10);
	// some empty space
	(new QWidget(hbox2))->setMinimumWidth(80);
	(new QWidget(hbox2))->setMinimumWidth(80);
	button_reload_ = new QPushButton("Reload tags", hbox2);
	button_cancel_ = new QPushButton("Cancel", hbox2);
	connect(button_reload_, SIGNAL(clicked()), SLOT(accept()));
	connect(button_cancel_, SIGNAL(clicked()), SLOT(reject()));




//	setSizeGripEnabled(true);
}

bool CtagsDialog::getLibc() {
#ifdef    ENABLE_STDLIBC_CTAGS
	return load_stdlib_->isChecked();
#else
	return false;
#endif
}

bool CtagsDialog::getPosixh() {
#ifdef    ENABLE_POSIXH_CTAGS
	return load_posixh_->isChecked();
#else
	return false;
#endif
}
bool CtagsDialog::getLatex() {
#ifdef    ENABLE_LATEX_CTAGS
	return load_latex_->isChecked();
#else
	return false;
#endif
}

bool CtagsDialog::getGenerateLocalTags() {
	return generate_local_tags_->isChecked();
}

QString CtagsDialog::getCmd() {
	return cmd_->text();
}
